@@ -1,10 +1,9 @@
 #encoding:utf-8
 from django.conf import settings
-from django.conf.urls.defaults import patterns, url, include
-from helmholtz.access_control.admin import access_control_admin
+from django.conf.urls.defaults import patterns, url
 
 urlpatterns = patterns('',
-    (r'^admin/', include(access_control_admin.urls)),
+    url(r'^reset/(?P<uidb36>[0-9A-Za-z]{1,13})-(?P<token>[0-9A-Za-z]{1,13}-[0-9A-Za-z]{1,20})/$', 'django.contrib.auth.views.password_reset_confirm', {'post_reset_redirect':'http://%s/visiondb/home/' % settings.SITE_DOMAIN}),
     url(r'^login/$', 'helmholtz.access_control.views.login_session', {'template_name':'login.html'}, name='login'),
     url(r'^logout/$', 'django.contrib.auth.views.logout_then_login', {'login_url':settings.LOGIN_URL}, name='logout'),
     url(r'^download/file/(?P<file_id>\w*)/$', 'helmholtz.access_control.views.download_file', name='download-file'),
