@@ -1,12 +1,12 @@
 #encoding:utf-8
 from django.contrib import admin
-from helmholtz.electrophysiology.models import ElectricalRecordingMode, ElectricalSignal, SharpElectrode, PatchElectrode, DiscElectrode, SharpElectrodeConfiguration, PatchElectrodeConfiguration, DiscElectrodeConfiguration, EEG, EKG
+from helmholtz.electrophysiology.models import ElectricalRecordingMode, ElectricalChannel, SharpElectrode, PatchElectrode, DiscElectrode, SharpElectrodeConfiguration, PatchElectrodeConfiguration, DiscElectrodeConfiguration, EEG, EKG
 
 electrophysiology_admin = admin.site
 
 #electrical channel types and recording modes
 electrophysiology_admin.register(ElectricalRecordingMode)
-electrophysiology_admin.register(ElectricalSignal)
+electrophysiology_admin.register(ElectricalChannel)
 
 #physical electrodes
 electrophysiology_admin.register(SharpElectrode)
