@@ -1,6 +1,6 @@
 #encoding:utf-8
 from django.contrib import admin
-from helmholtz.equipment.models import Material, EquipmentType, Equipment, StereotaxicType, GenericEquipment, Device, SubSystem, Setup  
+from helmholtz.equipment.models import Material, EquipmentType, Equipment, RecordingPoint, StereotaxicType, GenericEquipment, Device, SubSystem, Setup  
 
 equipment_admin = admin.site
 
@@ -9,6 +9,7 @@ equipment_admin.register(Material)
 equipment_admin.register(EquipmentType)
 equipment_admin.register(StereotaxicType)
 equipment_admin.register(Equipment)
+equipment_admin.register(RecordingPoint)
 equipment_admin.register(GenericEquipment)
 equipment_admin.register(Device)
 
